@@ -17,9 +17,11 @@
     under the License.
 */
 
+const globals = require('globals');
+
 module.exports = {
-    env: {
-        browser: true
+    languageOptions: {
+        globals: globals.browser
     },
 
     rules: {
