@@ -17,8 +17,10 @@
     under the License.
 */
 
+const globals = require('globals');
+
 module.exports = {
-    env: {
-        jasmine: true
+    languageOptions: {
+        globals: globals.jasmine
     }
 };
